# This file is the entry point to configure your own services.
# Files in the packages/ subdirectory configure your dependencies.

# Put parameters here that don't need to change on each machine where the app is deployed
# https://symfony.com/doc/current/best_practices.html#use-parameters-for-application-configuration
parameters:
    app.mediaUrl: '%env(MEDIA_URL)%'

services:
    # default configuration for services in *this* file
    _defaults:
        autowire: true      # Automatically injects dependencies in your services.
        autoconfigure: true # Automatically registers your services as commands, event subscribers, etc.
        bind:
          $projectDir: '%kernel.project_dir%'
    # makes classes in src/ available to be used as services
    # this creates a service per class whose id is the fully-qualified class name
    App\:
        resource: '../src/'
        exclude:
            - '../src/DependencyInjection/'
            - '../src/Entity/'
            - '../src/Kernel.php'

    # add more service definitions when explicit configuration is needed
    # please note that last definitions always *replace* previous ones
    App\State\DeleteUserProcessor:
        bind:
            $processor: '@api_platform.doctrine.orm.state.persist_processor'

    App\Twig\Runtime\AppExtensionRuntime:
        arguments:
            $mediaUrl: '%env(MEDIA_URL)%'

    App\EventListener\VichUploaderListener:
        tags:
            - { name: kernel.event_listener, event: vich_uploader.pre_upload, method: onVichUploaderPreUpload }
            - { name: kernel.event_listener, event: vich_uploader.post_upload, method: onVichUploaderPostUpload }
            - { name: kernel.event_listener, event: vich_uploader.pre_remove, method: onVichUploaderPreRemove }

    App\Service\PhotoNamerService:
        autowire: true
        public: true

    App\Twig\Extension\AppExtension:
        tags: [ 'twig.extension' ]

    App\EventSubscriber\LayoutEventSubscriber:
        tags:
            - { name: kernel.event_subscriber }

    App\Service\ParameterService:
        arguments:
            $entityManager: '@doctrine.orm.entity_manager'
            $cache: '@cache.app'

    App\Service\Payment\BankTransferPayment:
        tags: [ 'app.payment_method' ]

    App\Service\Payment\SipagosPayment:
        tags: [ 'app.payment_method' ]

    App\Service\Payment\MercadoPagoPayment:
        tags: [ 'app.payment_method' ]

    App\Service\Payment\PaymentMethodManager:
        arguments:
            $paymentMethods: !tagged_iterator 'app.payment_method'

    App\Service\WSAAService:
        arguments:
            $container: '@service_container'
   
    App\Service\WSFEService:
        arguments:
            $container: '@service_container'
    
    App\Service\WSRegistryService:
        arguments:
            $container: '@service_container'